@@ -236,10 +236,8 @@ class Student(Base):
 
 class Personnel(Base):
     """
-    Модель "Сотрудники"
-    Статус: Выполняется
+    Сотрудник
     """
-
     __tablename__ = 'univer_personal'
 
     # Идентификатор
@@ -257,16 +255,69 @@ class Personnel(Base):
     first_name = Column('personal_name', String(100))
     middle_name = Column('personal_father_name', String(100))
 
+    # Дата рождения
+    birthdate = Column('personal_birthday_date', DateTime)
+
+    # Адрес проживания
+    address = Column('personal_adress', String())
+
+    # Рабочий адрес
+    work_address = Column('personal_work_adress', String())
+
+    # Рабочая электронная почта
+    work_email = Column('personal_work_email', String(50))
+
+    # Электронная почта
+    email = Column('personal_email', String(50))
+
+    # Рабочий телефон
+    work_phone = Column('personal_work_phone', String(50))
+
+    # Мобильный телефон
+    mobile_phone = Column('personal_mobile_phone', String(50))
+
+    # Домашний телефон
+    home_phone = Column('personal_home_phone', String(50))
+
+    # Пол
+    sex = Column('personal_sex', Integer)
+
     # Фамилия и Имя персонала транслитом
     last_name_translit = Column('personal_translit_sname', String(100))
     first_name_translit = Column('personal_translit_name', String(100))
-
-    # Электронная почта
-    work_email = Column('personal_work_email', String(50))
+    middle_name_translit = Column('personal_translit_fname', String(100))
 
     # ИИН сотрудника
     identify_code = Column('personal_identification_number', String(150))
 
+    # Серия документа
+    document_series = Column('personal_document_series', String())
+
+    # Номер документа
+    document_number = Column('personal_document_number', String())
+
+    # Дата выдачи документа
+    document_issue_date = Column('personal_document_issue_date', DateTime)
+
+    # Кем выдан документ
+    document_issued = Column('personal_document_issued', String(150))
+
+    # Национальность
+    nationality_id = Column(ForeignKey('univer_nationality.nationality_id'))
+    nationality = relationship('Nationality')
+
+    # Семейное положение
+    family_status_id = Column(ForeignKey(
+        'univer_family_status_1c.family_status_id'))
+    family_status = relationship('FamilyStatus')
+
+    # Гражданство
+    citizenship_id = Column(ForeignKey('univer_citizenship.citizenship_id'))
+    citizenship = relationship('Citizenship')
+
+    # Статус
+    status = Column(Integer)
+
     def __repr__(self):
         return '<Personnel {} (id={} user={} status={})>'.format(self, self.user_id, self.status)
 
